This crate contains kube-rs compatible bindings for Kubernetes custom resources for the mariadb.persistentsys group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
mariadb.persistentsys/v1alpha1
BackupMariaDBMonitor